@@ -24,7 +24,7 @@ class DAGDefinition:
     def __init__(self, **spec):
         self.spec = spec
 
-        for required in ["dag_id", "description", "start_date", "catchup", "default_args", "tags"]:
+        for required in ["dag_id", "description", "schedule_interval", "start_date", "catchup", "default_args", "tags"]:
             if required not in self.spec:
                 try:
                     self.spec[required] = getattr(self, required)
@@ -40,29 +40,33 @@ class DAGDefinition:
     def output_table(self) -> TableSchema:
         raise NotImplementedError()
 
-    def create(self):
-        def ETL():
-            # Extract
-            tables = self.extraction()
-            assert isinstance(tables, dict), "The input tables should be a dictionary"
+    def local(self, write=False):
+        # Extract
+        tables = self.extraction()
+        assert isinstance(tables, dict), "The input tables should be a dictionary"
 
-            tables = {name: table.df if hasattr(table, "df") else table for name, table in tables.items()}
+        tables = {name: table.df if hasattr(table, "df") else table for name, table in tables.items()}
 
-            jobs = {name: job for name, job in tables.items() if callable(job)}
-            tables.update(Async.handle(**jobs))
+        jobs = {name: job for name, job in tables.items() if callable(job)}
+        tables.update(Async.handle(**jobs))
 
-            # Transform
-            definition = self.transformation(**tables)
+        # Transform
+        definition = self.transformation(**tables)
 
-            # Load
+        # Load
+        if write:
             self.output_table().replace_with(definition)
+        else:
+            return definition
 
-        dag = DAG(**self.spec)
-        compute = PythonOperator(
-            task_id='etl_tasks',
-            python_callable=ETL,
-            dag=dag,
-        )
+    def create(self, dag=None):
+        if dag is None:
+            dag = DAG(**self.spec)
+        else:
+            for key, value in self.spec.items():
+                setattr(dag, key, value)
+
+        compute = PythonOperator(task_id='etl_tasks', python_callable=lambda: self.local(write=True), dag=dag)
 
         if hasattr(self, "dependencies"):
             subscribe_to(self.spec["dag_id"], self.dependencies) >> compute
@@ -70,4 +74,5 @@ class DAGDefinition:
         if hasattr(self, "notify"):
             compute >> notify(self.spec["dag_id"], self.notify)
 
-        return dag
+        globals()[self.spec["dag_id"]] = dag
+        return globals()[self.spec["dag_id"]]
